/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_KQqFhxQH);
  numBytes += sPhasor_k_init(&sPhasor_2VG3X3r5, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_XemIG5Th);
  numBytes += sRPole_init(&sRPole_PDzgnrw8);
  numBytes += sRPole_init(&sRPole_hDlsx5y7);
  numBytes += sTabhead_init(&sTabhead_Ocl8LiRv, &hTable_oUDuDfw2);
  numBytes += sTabread_init(&sTabread_6wC9QuJh, &hTable_oUDuDfw2, false);
  numBytes += sTabread_init(&sTabread_zHr5fJVP, &hTable_oUDuDfw2, false);
  numBytes += sLine_init(&sLine_1FAexhvl);
  numBytes += sTabhead_init(&sTabhead_BelobxY4, &hTable_3gHGUZQw);
  numBytes += sTabread_init(&sTabread_dzHsAU2J, &hTable_3gHGUZQw, false);
  numBytes += sTabread_init(&sTabread_7nrr7SUU, &hTable_3gHGUZQw, false);
  numBytes += sLine_init(&sLine_AWGo3yK8);
  numBytes += sTabwrite_init(&sTabwrite_DMAq8IuW, &hTable_3gHGUZQw);
  numBytes += sTabwrite_init(&sTabwrite_Bea1Fg46, &hTable_oUDuDfw2);
  numBytes += cVar_init_f(&cVar_SBqZfwSH, 0.0f);
  numBytes += cVar_init_f(&cVar_5smHpVZH, 0.0f);
  numBytes += cVar_init_f(&cVar_DObrmYd6, 0.0f);
  numBytes += cVar_init_f(&cVar_DGXXJOt5, 0.0f);
  numBytes += cVar_init_s(&cVar_6PbKQZdX, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_b1NP3W1C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WzUcsSV3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pYRRNfa6, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_bluqjWky, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_fUBSKsaV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hTAlgMI4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H7e9e9jO, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_0Tthd0HB, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UzlBbNpI, 0.0f);
  numBytes += hTable_init(&hTable_3gHGUZQw, 256);
  numBytes += cDelay_init(this, &cDelay_GACJfM9g, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3pkiS0ek, 0.0f);
  numBytes += hTable_init(&hTable_oUDuDfw2, 256);
  numBytes += cVar_init_f(&cVar_73Eyqpgz, 14.0f);
  numBytes += cBinop_init(&cBinop_PpiLnwGD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_MHyODWmI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ojOpKKQg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_uVP83DhI, 14.0f);
  numBytes += cBinop_init(&cBinop_jkNyy7Mm, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_DS29eeF4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LqgeaqkE, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_KmC1Hrrv, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_iXbB31bD, 1, -1);
  numBytes += cVar_init_f(&cVar_L1FB88Yo, 0.2f);
  numBytes += cSlice_init(&cSlice_a2kAIeCn, 1, -1);
  numBytes += cVar_init_f(&cVar_aogwCkAF, 0.0f);
  numBytes += cSlice_init(&cSlice_j4RndBzl, 1, -1);
  numBytes += cVar_init_f(&cVar_KOMU6SYd, 2.0f);
  numBytes += cSlice_init(&cSlice_Fl99h4A5, 1, -1);
  numBytes += cVar_init_f(&cVar_IAen2eDa, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_3gHGUZQw);
  hTable_free(&hTable_oUDuDfw2);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_3gHGUZQw; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_oUDuDfw2; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dnEbK2BR_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rfwyHt26_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oCpVzefn_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oD7rm4ni_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rmrPcD4D_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UWnUQUw0_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NQt2kvtv_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uupqxNoX_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yUs8KEzk_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_SBqZfwSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yjH5FCad_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_5smHpVZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lvdOnbWR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_DObrmYd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Q4QCebZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_DGXXJOt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xcQ59iBo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_cXK0iros_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wCINzjrI_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_wCINzjrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_2VG3X3r5, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_rdXs3CPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TMIkghii_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_TMIkghii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1VQ2QIsp_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_6PbKQZdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PQxFu5KM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_xG3D8b9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mjUN4Axn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_b1NP3W1C, m);
}

void Heavy_WSTD_FLANGR::cBinop_1VQ2QIsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WzUcsSV3, m);
}

void Heavy_WSTD_FLANGR::cMsg_PQxFu5KM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xG3D8b9v_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_mjUN4Axn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pYRRNfa6, m);
}

void Heavy_WSTD_FLANGR::cMsg_JdkSZnNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LvHBlR1U_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_LvHBlR1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_k94u4vsd_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_bluqjWky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PIeyhFVM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_jIuSOKI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SwZgssTv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fUBSKsaV, m);
}

void Heavy_WSTD_FLANGR::cBinop_k94u4vsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hTAlgMI4, m);
}

void Heavy_WSTD_FLANGR::cMsg_PIeyhFVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jIuSOKI1_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_SwZgssTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_H7e9e9jO, m);
}

void Heavy_WSTD_FLANGR::cBinop_pqr7JFRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9xpFzGub_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9xpFzGub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_10HqUzH6_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_IgXr5wlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2zeTyiQJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_cppH7dXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6sq7kZ9z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_10HqUzH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Krb1XttD_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Krb1XttD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_acYV4BaF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L0XnpDjV_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_L0XnpDjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cg6KtCHW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_acYV4BaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1otWMimU_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_1otWMimU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_v3nryRrY_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_cg6KtCHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2m4dld6b_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_2m4dld6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_V2J1wUWL_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_v3nryRrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_IgXr5wlA_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_V2J1wUWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_cppH7dXN_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QGkovQek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SY4Iwmxt_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_SY4Iwmxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kAfE6sOb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_xBZfTGZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Nuq0VOGv_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_Nuq0VOGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Lpl0qp8Y_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_0Tthd0HB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0Tthd0HB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UzlBbNpI, 0, m, &cDelay_UzlBbNpI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Tthd0HB, 0, m, &cDelay_0Tthd0HB_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DMAq8IuW, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_UzlBbNpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UzlBbNpI, m);
  cMsg_JsFT2yLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_NqtxHzm3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ySwFNPF4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_ACOjjEqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1uLhyDzK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_3gHGUZQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_adWsyRNZ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Tthd0HB, 2, m, &cDelay_0Tthd0HB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gxcBkSWH_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_1uLhyDzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_3gHGUZQw, 0, m, &hTable_3gHGUZQw_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Lpl0qp8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_ACOjjEqW_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_JsFT2yLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_3gHGUZQw, 0, m, &hTable_3gHGUZQw_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_gxcBkSWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Tthd0HB, 0, m, &cDelay_0Tthd0HB_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_adWsyRNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UzlBbNpI, 2, m, &cDelay_UzlBbNpI_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ySwFNPF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DMAq8IuW, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_BkjhC6bJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_c8R4adGr_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_c8R4adGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_h9AyLw5G_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_GACJfM9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GACJfM9g, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3pkiS0ek, 0, m, &cDelay_3pkiS0ek_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GACJfM9g, 0, m, &cDelay_GACJfM9g_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Bea1Fg46, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_3pkiS0ek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3pkiS0ek, m);
  cMsg_2tKgAPNy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_Zta3sJOY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Zj6pJGBM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_KxlqnL1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iKWg0HH5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_oUDuDfw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hh8zGUMW_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GACJfM9g, 2, m, &cDelay_GACJfM9g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cHfpr3FB_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_iKWg0HH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_oUDuDfw2, 0, m, &hTable_oUDuDfw2_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_h9AyLw5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_KxlqnL1q_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_2tKgAPNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_oUDuDfw2, 0, m, &hTable_oUDuDfw2_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_cHfpr3FB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GACJfM9g, 0, m, &cDelay_GACJfM9g_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Hh8zGUMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_3pkiS0ek, 2, m, &cDelay_3pkiS0ek_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Zj6pJGBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Bea1Fg46, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_73Eyqpgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PpiLnwGD, HV_BINOP_MULTIPLY, 0, m, &cBinop_PpiLnwGD_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_3d8lvqFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rnQluCBm_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_rnQluCBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E6MDcAdh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_PpiLnwGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_HrsPvg20_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_VJuIJbY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PpiLnwGD, HV_BINOP_MULTIPLY, 1, m, &cBinop_PpiLnwGD_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_E6MDcAdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VJuIJbY9_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_HrsPvg20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_iSEVdoQZ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_iSEVdoQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FIJTYQMy_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ojOpKKQg, m);
}

void Heavy_WSTD_FLANGR::cBinop_FIJTYQMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MHyODWmI, m);
}

void Heavy_WSTD_FLANGR::cVar_uVP83DhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkNyy7Mm, HV_BINOP_MULTIPLY, 0, m, &cBinop_jkNyy7Mm_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_wlx3CTDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ELrUPSq9_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_ELrUPSq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A2z5UeI5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_jkNyy7Mm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_84hjj5hN_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_KFPGSLOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkNyy7Mm, HV_BINOP_MULTIPLY, 1, m, &cBinop_jkNyy7Mm_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_A2z5UeI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KFPGSLOQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_84hjj5hN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_P0Asb8jM_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_P0Asb8jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7UdZCjpf_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LqgeaqkE, m);
}

void Heavy_WSTD_FLANGR::cBinop_7UdZCjpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DS29eeF4, m);
}

void Heavy_WSTD_FLANGR::cMsg_kAfE6sOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XemIG5Th, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_oCGrNXYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_XjtbmYHA_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_LhzkounT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wrcXM91h_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_7CSdybpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_oCGrNXYO_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_O68xJTJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VlqYwU9e_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_VlqYwU9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KmC1Hrrv, HV_BINOP_MULTIPLY, 1, m, &cBinop_KmC1Hrrv_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_wrcXM91h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_O68xJTJj_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_KmC1Hrrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qCCYJr9J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_XjtbmYHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KmC1Hrrv, HV_BINOP_MULTIPLY, 0, m, &cBinop_KmC1Hrrv_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_qCCYJr9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AWGo3yK8, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_dZmVWWGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_nmFXRJbd_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_nmFXRJbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LhzkounT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7CSdybpe_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_99kogdr2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iXbB31bD, 0, m, &cSlice_iXbB31bD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DGRNYgUc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_iXbB31bD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xrQMsI8G_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xrQMsI8G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_L1FB88Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xrQMsI8G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_xrQMsI8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UWnUQUw0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_DGRNYgUc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_a2kAIeCn, 0, m, &cSlice_a2kAIeCn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MhGS8jrt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_a2kAIeCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AhFqfSs4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AhFqfSs4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_aogwCkAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AhFqfSs4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_AhFqfSs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rmrPcD4D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_MhGS8jrt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_j4RndBzl, 0, m, &cSlice_j4RndBzl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QtMYGaQI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_j4RndBzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kep7bg8W_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kep7bg8W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_KOMU6SYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kep7bg8W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_kep7bg8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uupqxNoX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_QtMYGaQI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Fl99h4A5, 0, m, &cSlice_Fl99h4A5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_Fl99h4A5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IsH9sQzp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IsH9sQzp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_IAen2eDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IsH9sQzp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_IsH9sQzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NQt2kvtv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_2zeTyiQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1FAexhvl, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_6sq7kZ9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KQqFhxQH, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_xcQ59iBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_99kogdr2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_yjH5FCad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_99kogdr2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_lvdOnbWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_99kogdr2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_8Q4QCebZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_99kogdr2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_vuR7EAix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DGXXJOt5, 0, m, &cVar_DGXXJOt5_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Sp4bD0ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SBqZfwSH, 0, m, &cVar_SBqZfwSH_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_kLZOGyzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DObrmYd6, 0, m, &cVar_DObrmYd6_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_uupqxNoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_cXK0iros_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_rmrPcD4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_dZmVWWGO_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_yUs8KEzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3d8lvqFS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_73Eyqpgz, 0, m, &cVar_73Eyqpgz_sendMessage);
  cMsg_wlx3CTDS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uVP83DhI, 0, m, &cVar_uVP83DhI_sendMessage);
  cMsg_xBZfTGZV_sendMessage(_c, 0, m);
  cMsg_BkjhC6bJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_L1FB88Yo, 0, m, &cVar_L1FB88Yo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aogwCkAF, 0, m, &cVar_aogwCkAF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KOMU6SYd, 0, m, &cVar_KOMU6SYd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IAen2eDa, 0, m, &cVar_IAen2eDa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6PbKQZdX, 0, m, &cVar_6PbKQZdX_sendMessage);
  cMsg_rdXs3CPp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bluqjWky, 0, m, &cVar_bluqjWky_sendMessage);
  cMsg_JdkSZnNa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_NQt2kvtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pqr7JFRB_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_UWnUQUw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QGkovQek_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_oD7rm4ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5smHpVZH, 0, m, &cVar_5smHpVZH_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_oCpVzefn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_vuR7EAix_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_rfwyHt26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_kLZOGyzl_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_dnEbK2BR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Sp4bD0ko_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_KQqFhxQH, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_2VG3X3r5, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_XemIG5Th, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_ojOpKKQg, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_MHyODWmI, VOf(Bf3));
    __hv_rpole_f(&sRPole_PDzgnrw8, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_LqgeaqkE, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_DS29eeF4, VOf(Bf4));
    __hv_rpole_f(&sRPole_hDlsx5y7, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_Ocl8LiRv, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_WzUcsSV3, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_pYRRNfa6, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_b1NP3W1C, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_6wC9QuJh, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_zHr5fJVP, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_1FAexhvl, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_BelobxY4, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_hTAlgMI4, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_H7e9e9jO, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_fUBSKsaV, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_dzHsAU2J, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_7nrr7SUU, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_AWGo3yK8, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_DMAq8IuW, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_Bea1Fg46, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
