/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvSignalTabread.h"
#include "HvControlBinop.h"
#include "HvSignalPhasor.h"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"
#include "HvSignalDel1.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvControlUnop.h"
#include "HvSignalTabwrite.h"
#include "HvSignalLine.h"
#include "HvSignalRPole.h"
#include "HvSignalVar.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_SBqZfwSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5smHpVZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DObrmYd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DGXXJOt5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cXK0iros_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wCINzjrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rdXs3CPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TMIkghii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6PbKQZdX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xG3D8b9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1VQ2QIsp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PQxFu5KM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mjUN4Axn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JdkSZnNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LvHBlR1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bluqjWky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jIuSOKI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k94u4vsd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PIeyhFVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SwZgssTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pqr7JFRB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9xpFzGub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IgXr5wlA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cppH7dXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_10HqUzH6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Krb1XttD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L0XnpDjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_acYV4BaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1otWMimU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cg6KtCHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2m4dld6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v3nryRrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V2J1wUWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QGkovQek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SY4Iwmxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xBZfTGZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Nuq0VOGv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_0Tthd0HB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UzlBbNpI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NqtxHzm3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ACOjjEqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_3gHGUZQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1uLhyDzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lpl0qp8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JsFT2yLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gxcBkSWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_adWsyRNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ySwFNPF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BkjhC6bJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_c8R4adGr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GACJfM9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3pkiS0ek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Zta3sJOY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_KxlqnL1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_oUDuDfw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iKWg0HH5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h9AyLw5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2tKgAPNy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cHfpr3FB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hh8zGUMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zj6pJGBM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_73Eyqpgz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3d8lvqFS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rnQluCBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PpiLnwGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VJuIJbY9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E6MDcAdh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HrsPvg20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iSEVdoQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FIJTYQMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uVP83DhI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wlx3CTDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ELrUPSq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jkNyy7Mm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KFPGSLOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A2z5UeI5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_84hjj5hN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P0Asb8jM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7UdZCjpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kAfE6sOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_oCGrNXYO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LhzkounT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7CSdybpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O68xJTJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VlqYwU9e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wrcXM91h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KmC1Hrrv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XjtbmYHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qCCYJr9J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dZmVWWGO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nmFXRJbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_99kogdr2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_iXbB31bD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L1FB88Yo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xrQMsI8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DGRNYgUc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_a2kAIeCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aogwCkAF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AhFqfSs4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MhGS8jrt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_j4RndBzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KOMU6SYd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_kep7bg8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QtMYGaQI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Fl99h4A5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IAen2eDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IsH9sQzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2zeTyiQJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6sq7kZ9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xcQ59iBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yjH5FCad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lvdOnbWR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Q4QCebZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vuR7EAix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sp4bD0ko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kLZOGyzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uupqxNoX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rmrPcD4D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yUs8KEzk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NQt2kvtv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UWnUQUw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oD7rm4ni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oCpVzefn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rfwyHt26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dnEbK2BR_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_KQqFhxQH;
  SignalPhasor sPhasor_2VG3X3r5;
  SignalLine sLine_XemIG5Th;
  SignalRPole sRPole_PDzgnrw8;
  SignalRPole sRPole_hDlsx5y7;
  SignalTabhead sTabhead_Ocl8LiRv;
  SignalTabread sTabread_6wC9QuJh;
  SignalTabread sTabread_zHr5fJVP;
  SignalLine sLine_1FAexhvl;
  SignalTabhead sTabhead_BelobxY4;
  SignalTabread sTabread_dzHsAU2J;
  SignalTabread sTabread_7nrr7SUU;
  SignalLine sLine_AWGo3yK8;
  SignalTabwrite sTabwrite_DMAq8IuW;
  SignalTabwrite sTabwrite_Bea1Fg46;
  ControlVar cVar_SBqZfwSH;
  ControlVar cVar_5smHpVZH;
  ControlVar cVar_DObrmYd6;
  ControlVar cVar_DGXXJOt5;
  ControlBinop cBinop_cXK0iros;
  ControlBinop cBinop_wCINzjrI;
  ControlVar cVar_6PbKQZdX;
  ControlBinop cBinop_1VQ2QIsp;
  ControlBinop cBinop_mjUN4Axn;
  SignalVarf sVarf_b1NP3W1C;
  SignalVarf sVarf_WzUcsSV3;
  SignalVarf sVarf_pYRRNfa6;
  ControlVar cVar_bluqjWky;
  ControlBinop cBinop_k94u4vsd;
  ControlBinop cBinop_SwZgssTv;
  SignalVarf sVarf_fUBSKsaV;
  SignalVarf sVarf_hTAlgMI4;
  SignalVarf sVarf_H7e9e9jO;
  ControlBinop cBinop_pqr7JFRB;
  ControlBinop cBinop_9xpFzGub;
  ControlBinop cBinop_10HqUzH6;
  ControlBinop cBinop_Krb1XttD;
  ControlBinop cBinop_1otWMimU;
  ControlBinop cBinop_2m4dld6b;
  ControlBinop cBinop_v3nryRrY;
  ControlBinop cBinop_V2J1wUWL;
  ControlBinop cBinop_QGkovQek;
  ControlBinop cBinop_SY4Iwmxt;
  ControlDelay cDelay_0Tthd0HB;
  ControlDelay cDelay_UzlBbNpI;
  ControlBinop cBinop_ACOjjEqW;
  HvTable hTable_3gHGUZQw;
  ControlBinop cBinop_Lpl0qp8Y;
  ControlDelay cDelay_GACJfM9g;
  ControlDelay cDelay_3pkiS0ek;
  ControlBinop cBinop_KxlqnL1q;
  HvTable hTable_oUDuDfw2;
  ControlBinop cBinop_h9AyLw5G;
  ControlVar cVar_73Eyqpgz;
  ControlBinop cBinop_PpiLnwGD;
  ControlBinop cBinop_VJuIJbY9;
  SignalVarf sVarf_MHyODWmI;
  ControlBinop cBinop_HrsPvg20;
  ControlBinop cBinop_iSEVdoQZ;
  ControlBinop cBinop_FIJTYQMy;
  SignalVarf sVarf_ojOpKKQg;
  ControlVar cVar_uVP83DhI;
  ControlBinop cBinop_jkNyy7Mm;
  ControlBinop cBinop_KFPGSLOQ;
  SignalVarf sVarf_DS29eeF4;
  ControlBinop cBinop_84hjj5hN;
  ControlBinop cBinop_P0Asb8jM;
  ControlBinop cBinop_7UdZCjpf;
  SignalVarf sVarf_LqgeaqkE;
  ControlBinop cBinop_O68xJTJj;
  ControlBinop cBinop_VlqYwU9e;
  ControlBinop cBinop_wrcXM91h;
  ControlBinop cBinop_KmC1Hrrv;
  ControlBinop cBinop_XjtbmYHA;
  ControlBinop cBinop_dZmVWWGO;
  ControlBinop cBinop_nmFXRJbd;
  ControlSlice cSlice_iXbB31bD;
  ControlVar cVar_L1FB88Yo;
  ControlSlice cSlice_a2kAIeCn;
  ControlVar cVar_aogwCkAF;
  ControlSlice cSlice_j4RndBzl;
  ControlVar cVar_KOMU6SYd;
  ControlSlice cSlice_Fl99h4A5;
  ControlVar cVar_IAen2eDa;
  ControlBinop cBinop_vuR7EAix;
  ControlBinop cBinop_Sp4bD0ko;
  ControlBinop cBinop_kLZOGyzl;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
